.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.graph.entities package
===============================

Modules
-------
.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.graph.entities.bibliographic_entity
   entities/oc_ocdm.graph.entities.identifier

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.graph.entities.bibliographic
